qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Qemu-devel] [6492] Replace noreturn with QEMU_NORETURN


From: malc
Subject: [Qemu-devel] [6492] Replace noreturn with QEMU_NORETURN
Date: Sun, 01 Feb 2009 22:19:28 +0000

Revision: 6492
          http://svn.sv.gnu.org/viewvc/?view=rev&root=qemu&revision=6492
Author:   malc
Date:     2009-02-01 22:19:27 +0000 (Sun, 01 Feb 2009)

Log Message:
-----------
Replace noreturn with QEMU_NORETURN

Thanks to Robert Riebisch for analysis [1]

[1] http://marc.info/?l=qemu-devel&m=123352293319271&w=2

Modified Paths:
--------------
    trunk/cpu-all.h
    trunk/darwin-user/signal.c
    trunk/exec-all.h
    trunk/linux-user/signal.c
    trunk/qemu-common.h
    trunk/qemu-img.c
    trunk/target-i386/exec.h
    trunk/target-i386/op_helper.c

Modified: trunk/cpu-all.h
===================================================================
--- trunk/cpu-all.h     2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/cpu-all.h     2009-02-01 22:19:27 UTC (rev 6492)
@@ -753,7 +753,7 @@
                           int (*cpu_fprintf)(FILE *f, const char *fmt, ...),
                           int flags);
 
-void noreturn cpu_abort(CPUState *env, const char *fmt, ...)
+void QEMU_NORETURN cpu_abort(CPUState *env, const char *fmt, ...)
     __attribute__ ((__format__ (__printf__, 2, 3)));
 extern CPUState *first_cpu;
 extern CPUState *cpu_single_env;

Modified: trunk/darwin-user/signal.c
===================================================================
--- trunk/darwin-user/signal.c  2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/darwin-user/signal.c  2009-02-01 22:19:27 UTC (rev 6492)
@@ -133,7 +133,7 @@
 }
 
 /* abort execution with signal */
-void noreturn force_sig(int sig)
+void QEMU_NORETURN force_sig(int sig)
 {
     int host_sig;
     host_sig = target_to_host_signal(sig);

Modified: trunk/exec-all.h
===================================================================
--- trunk/exec-all.h    2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/exec-all.h    2009-02-01 22:19:27 UTC (rev 6492)
@@ -85,7 +85,7 @@
                               target_ulong pc, target_ulong cs_base, int flags,
                               int cflags);
 void cpu_exec_init(CPUState *env);
-void noreturn cpu_loop_exit(void);
+void QEMU_NORETURN cpu_loop_exit(void);
 int page_unprotect(target_ulong address, unsigned long pc, void *puc);
 void tb_invalidate_phys_page_range(target_phys_addr_t start, 
target_phys_addr_t end,
                                    int is_cpu_write_access);

Modified: trunk/linux-user/signal.c
===================================================================
--- trunk/linux-user/signal.c   2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/linux-user/signal.c   2009-02-01 22:19:27 UTC (rev 6492)
@@ -349,7 +349,7 @@
 }
 
 /* abort execution with signal */
-static void noreturn force_sig(int sig)
+static void QEMU_NORETURN force_sig(int sig)
 {
     int host_sig;
     host_sig = target_to_host_signal(sig);

Modified: trunk/qemu-common.h
===================================================================
--- trunk/qemu-img.c    2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/qemu-img.c    2009-02-01 22:19:27 UTC (rev 6492)
@@ -34,7 +34,7 @@
 /* Default to cache=writeback as data integrity is not important for qemu-tcg. 
*/
 #define BRDV_O_FLAGS BDRV_O_CACHE_WB
 
-static void noreturn error(const char *fmt, ...)
+static void QEMU_NORETURN error(const char *fmt, ...)
 {
     va_list ap;
     va_start(ap, fmt);

Modified: trunk/target-i386/exec.h
===================================================================
--- trunk/target-i386/exec.h    2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/target-i386/exec.h    2009-02-01 22:19:27 UTC (rev 6492)
@@ -63,8 +63,8 @@
                   target_ulong next_eip, int is_hw);
 void do_interrupt_user(int intno, int is_int, int error_code,
                        target_ulong next_eip);
-void noreturn raise_exception_err(int exception_index, int error_code);
-void noreturn raise_exception(int exception_index);
+void QEMU_NORETURN raise_exception_err(int exception_index, int error_code);
+void QEMU_NORETURN raise_exception(int exception_index);
 void do_smm_enter(void);
 
 /* n must be a constant to be efficient */

Modified: trunk/target-i386/op_helper.c
===================================================================
--- trunk/target-i386/op_helper.c       2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/target-i386/op_helper.c       2009-02-01 22:19:27 UTC (rev 6492)
@@ -1303,8 +1303,8 @@
  * EIP value AFTER the interrupt instruction. It is only relevant if
  * is_int is TRUE.
  */
-static void noreturn raise_interrupt(int intno, int is_int, int error_code,
-                                     int next_eip_addend)
+static void QEMU_NORETURN raise_interrupt(int intno, int is_int, int 
error_code,
+                                          int next_eip_addend)
 {
     if (!is_int) {
         helper_svm_check_intercept_param(SVM_EXIT_EXCP_BASE + intno, 
error_code);






reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- trunk/qemu-common.h 2009-02-01 19:26:20 UTC (rev 6491)
+++ trunk/qemu-common.h 2009-02-01 22:19:27 UTC (rev 6492)
@@ -8,9 +8,9 @@
 #include <windows.h>
 #endif
 
-#define noreturn __attribute__ ((__noreturn__))
+#define QEMU_NORETURN __attribute__ ((__noreturn__))
 
 /* Hack around the mess dyngen-exec.h causes: We need noreturn in files that
that
    cannot include the following headers without conflicts. This condition has
    to be removed once dyngen is gone. */
 #ifndef __DYNGEN_EXEC_H__
@@ -144,7 +144,7 @@
 
 /* Error handling.  */
 
-void noreturn hw_error(const char *fmt, ...)
+void QEMU_NORETURN hw_error(const char *fmt, ...)
     __attribute__ ((__format__ (__printf__, 1, 2)));
 
 /* IO callbacks.  */
@@ -8,9 +8,9 @@
 
-/* Hack around the mess dyngen-exec.h causes: We need noreturn in files that
+/* Hack around the mess dyngen-exec.h causes: We need QEMU_NORETURN in files 
that
    cannot include the following headers without conflicts. This condition has

Modified: trunk/qemu-img.c
===================================================================